summaryrefslogtreecommitdiffstats
path: root/scripts/kde-emacs/dirvars.el
diff options
context:
space:
mode:
Diffstat (limited to 'scripts/kde-emacs/dirvars.el')
-rw-r--r--scripts/kde-emacs/dirvars.el12
1 files changed, 6 insertions, 6 deletions
diff --git a/scripts/kde-emacs/dirvars.el b/scripts/kde-emacs/dirvars.el
index 94f682b0..5fba18e7 100644
--- a/scripts/kde-emacs/dirvars.el
+++ b/scripts/kde-emacs/dirvars.el
@@ -96,18 +96,18 @@ The FILE-NAME specifies the file name to search for."
(setq dir-name (expand-file-name dir-name))
;; Move up in the dir hierarchy till we find a change log file.
(let ((file1 (concat dir-name file-name))
- tqparent-dir)
+ parent-dir)
(while (and (not (file-exists-p file1))
- (progn (setq tqparent-dir
+ (progn (setq parent-dir
(file-name-directory
(directory-file-name
(file-name-directory file1))))
;; Give up if we are already at the root dir.
(not (string= (file-name-directory file1)
- tqparent-dir))))
- ;; Move up to the tqparent dir and try again.
- (setq file1 (expand-file-name file-name tqparent-dir)))
- ;; If we found the file in a tqparent dir, use that. Otherwise,
+ parent-dir))))
+ ;; Move up to the parent dir and try again.
+ (setq file1 (expand-file-name file-name parent-dir)))
+ ;; If we found the file in a parent dir, use that. Otherwise,
;; return nil
(if (or (get-file-buffer file1) (file-exists-p file1))
file1